#
# spec file for package bzrtp
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover   0
Name:           bzrtp
Version:        5.2.98
Release:        1.1
Summary:        ZRTP keys exchange protocol implementation
License:        GPL-3.0-or-later
Group:          Productivity/Telephony/Utilities
URL:            https://linphone.org/
Source:         https://gitlab.linphone.org/BC/public/bzrtp/-/archive/%{version}/%{name}-%{version}.tar.bz2
Source1:        baselibs.conf
# PATCH-FIX-OPENSUSE bzrtp-fix-pkgconfig.patch sor.alexei@meowr.ru -- Install libbzrtp.pc.
Patch0:         bzrtp-fix-pkgconfig.patch
Patch1:         set_current_version.patch
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(bctoolbox) >= %{version}
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(sqlite3)

%description
bzrtp is an implementation of the ZRTP key exchange protocol.
The library written in C89.

%package -n lib%{name}%{sover}
Summary:        ZRTP key exchange protocol implementation
Group:          Productivity/Telephony/Utilities

%description -n lib%{name}%{sover}
bzrtp is an implementation of the ZRTP key exchange protocol.
The library written in C89.

%package devel
Summary:        Development files for libbzrtp
Group:          Development/Libraries/C and C++
Requires:       lib%{name}%{sover} = %{version}

%description devel
The libbzrtp development package includes the header files,
libraries, development tools necessary for compiling and linking
application which will use libbzrtp.

%prep
%autosetup -p1

%build
%cmake -DENABLE_STATIC=OFF
%cmake_build

%install
%cmake_install

%post -n lib%{name}%{sover} -p /sbin/ldconfig
%postun -n lib%{name}%{sover} -p /sbin/ldconfig

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}.so.%{sover}*

%files devel
%license LICENSE.txt
%doc README.md
%{_includedir}/%{name}/
%{_libdir}/lib%{name}.so
%{_datadir}/%{name}/
%{_libdir}/pkgconfig/lib%{name}.pc

%changelog
* Mon Aug 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.98 (no changelog)
* Wed Jun 28 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.73 (no changelog)
* Fri Apr  7 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.49 (no changelog)
* Wed Mar  8 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.30 (no changelog)
- Add set_current_version.patch
* Fri Feb 17 2023 Avinesh Kumar <avinesh.kumar@suse.com>
- Update to version 5.2.16:
  * Improve debug trace
* Wed Jan 11 2023 Giacomo Comes <gcomes.obs@gmail.com> - 5.2.9
- Update to version 5.2.9:
  * no changes
* Wed Jan  4 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.2.6:
  * Support for GoClear/ClearACK messages
  * KEM version and support for Hybrid PostQuantum key agreement algorithms
* Mon Oct 17 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.64 (no changelog).
* Fri Jul  8 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.45:
  * no changelog
* Wed Jun  8 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.1.32
- Update to version 5.1.32:
  * Cmake support for build from flexisip
- revert license tag change
* Thu Mar 24 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.1.12:
  * no changelog
* Tue Mar  1 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.1.3 (no changelog)
* Tue Feb  1 2022 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.67
- Update to version 5.0.67:
  * no changes
- fix license tag
* Tue Jan 18 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to version 5.0.66:
  * no changelog
* Sun Nov 21 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.53
- Update to version 5.0.53:
  * no changes
* Mon Nov  8 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.49
- Update to 5.0.49:
  * no changes
* Tue Nov  2 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.46
- Update to 5.0.46:
  * no changes
* Tue Oct 19 2021 Giacomo Comes <gcomes.obs@gmail.com> - 5.0.36
- Update to 5.0.36:
  * Fix compilation issue with CLang 11
* Fri Oct 15 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.35:
  * no changelog
* Wed Jul 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 5.0.0, no changelog
* Tue Jun 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.20, no changelog
* Fri May 14 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.15 (no changelog)
* Wed Apr 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.10 (no changelog)
* Thu Apr 15 2021 Luiz Angelo Daros de Luca <luizluca@tre-sc.jus.br>
- Update to 4.5.3:
  * No changelog available.
* Wed Mar 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.5.0 (no changelog)
* Tue Mar  9 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.33 (no changelog)
* Mon Feb 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.29 (no changelog)
* Fri Jan 22 2021 Jan Engelhardt <jengelh@inai.de>
- Trim redundancies from description.
* Fri Jan 22 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.24 (no changelog)
* Thu Dec 31 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.21 (no changelog)
* Wed Dec  2 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.13 (no changelog)
* Thu Nov 12 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.7 (no changelog)
* Wed Nov  4 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.6 (no changelog)
* Wed Jul 29 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update the licence: it is now GPLv3+.
* Fri Jun 26 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.4.0 (no changelog)
* Tue Mar  3 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 4.3.1 (no changelog)
* Wed Nov 20 2019 Simon Lees <sflees@suse.de>
- %%make_jobs is depricated replaced by %%cmake_build
- Use %%autosetup to simplify maintenance
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Sep 12 2018 Jan Engelhardt <jengelh@inai.de>
- Fix RPM group.
* Wed Sep  5 2018 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Move doc between subpackages
* Fri Jul 21 2017 sor.alexei@meowr.ru
- Update to version 1.0.6:
  * Bug fixes.
* Wed May 17 2017 sor.alexei@meowr.ru
- Update to version 1.0.5:
  * Bug fixes.
* Tue Sep 13 2016 sor.alexei@meowr.ru
- Switch to building with CMake.
- Add bzrtp-fix-pkgconfig.patch: Install libbzrtp.pc on CMake.
* Mon Sep 12 2016 sor.alexei@meowr.ru
- Update to version 1.0.4:
  * Build system fixes.
  * Security fix.
- Remove mbedtls2.patch.
* Fri Aug 12 2016 mpluskal@suse.com
- Add mbedtls2.patch to fix building with mbedtls2
* Thu Nov 19 2015 mpluskal@suse.com
- Update to 1.0.3
  * build system fixes
- Make build more verbose
* Mon Jul 20 2015 mpluskal@suse.com
- Update to 1.0.2
  * bug fixes
* Mon Mar 23 2015 sor.alexei@meowr.ru
- Initial package.
